@@ -46,6 +46,47 @@ time_t c_parse_unix_time(char *fmt, char *src) {
     return mktime(&dst);
 }
 
+#if !defined(HAVE_TIMEGM)
+/* This part is for Solaris that doesn't have timegm.
+ * The copyright notice of timegm and is_leap is as below:
+ *
+ * Copyright (c) 1997 Kungliga Tekniska H.gskolan
+ * (Royal Institute of Technology, Stockholm, Sweden).
+ * All rights reserved. 
+ */
+
+static int
+is_leap(unsigned y)
+{
+  y += 1900;
+  return (y % 4) == 0 && ((y % 100) != 0 || (y % 400) == 0);
+}
+
+static time_t
+timegm (struct tm *tm)
+{
+  static const unsigned ndays[2][12] ={
+    {31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31},
+    {31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31}};
+  time_t res = 0;
+  unsigned i;
+
+  for (i = 70; i < tm->tm_year; ++i)
+    res += is_leap(i) ? 366 : 365;
+
+  for (i = 0; i < tm->tm_mon; ++i)
+    res += ndays[is_leap(tm->tm_year)][i];
+  res += tm->tm_mday - 1;
+  res *= 24;
+  res += tm->tm_hour;
+  res *= 60;
+  res += tm->tm_min;
+  res *= 60;
+  res += tm->tm_sec;
+  return res;
+}
+#endif /* HAVE_TIMEGM */
+
 time_t c_parse_unix_time_gmt(char *fmt, char *src) {
     struct tm dst;
     init_locale();
